@@ -7,26 +7,32 @@
 #' @keywords Hansard API
 #' @export
 #' @examples \dontrun{
-#' x <- hansard_generic('elections.json')
+#'
+#'  x <- hansard_generic('elections.json')
+#'
 #' }
 
 
 hansard_generic <- function(path) {
+    
     url <- modify_url("http://lda.data.parliament.uk/", path = path)
-
+    
     message("Connecting to API")
-
+    
     mydata <- jsonlite::fromJSON(url)
-
+    
     genericJPages <- round(mydata$result$totalResults/mydata$result$itemsPerPage, digits = 0)
-
+    
     pages <- list()
-
+    
     for (i in 0:genericJPages) {
         mydata <- jsonlite::fromJSON(paste0(url, "?_page=", i), flatten = TRUE)
         message("Retrieving page ", i + 1, " of ", genericJPages + 1)
         pages[[i + 1]] <- mydata$result$items
     }
-
-    df <- jsonlite::rbind.pages(pages[sapply(pages, length) > 0])  #The data frame that is returned
+    
+    df <- dplyr::bind_rows(pages)
+    
+    df
+    
 }
